@@ -1,13 +1,13 @@
-# $Id: Liberal.pm 1 2006-03-06 05:09:29Z daisuke $
+# $Id: /mirror/perl/XML-RSS-Liberal/trunk/lib/XML/RSS/Liberal.pm 5376 2007-02-01T09:53:51.285589Z daisuke  $
 #
-# Copyright (c) 2006 Daisuke Maki <dmaki@cpan.org>
+# Copyright (c) 2006-2007 Daisuke Maki <daisuke@endeworks.jp>
 # All rights reserved.
 
 package XML::RSS::Liberal;
 use strict;
 use base qw(XML::RSS::LibXML);
 use vars qw($VERSION);
-$VERSION = '0.01';
+$VERSION = '0.02';
 
 my $LoadedParser = 0;
 sub _create_parser
@@ -20,7 +20,7 @@ sub _create_parser
     }
 
     if (! $self->{_parser}) {
-        $self->{_parser} = XML::RSS::Liberal::Parser->new('LibXML');
+        $self->{_parser} = XML::RSS::Liberal::Parser->new();
     }
 
     return $self->{_parser};
@@ -47,8 +47,8 @@ XML::RSS::Liberal - XML::RSS With A Liberal Parser
 
 XML::RSS::Liberal is a subclass of XML::RSS::LibXML, for those of you who
 want to parse broken RSS files (as they often are). It uses XML::Liberal as
-its core parser, and therefore whatever broken XML you provided, as long
-as XML::Liberal can tolerate it.
+its core parser, and therefore it can parse whatever broken XML you provided,
+so as long as XML::Liberal can tolerate it.
 
 =head1 SEE ALSO
 
@@ -57,6 +57,6 @@ L<XML::Liberal>
 
 =head1 AUTHORS
 
-Daisuke Maki E<lt>dmaki@cpan.orgE<gt>, Tatsuhiko Miyagawa E<lt>miyagawa@bulknews.netE<gt>
+Daisuke Maki E<lt>daisuke@endeworks.jpE<gt>, Tatsuhiko Miyagawa E<lt>miyagawa@bulknews.netE<gt>
 
 =cut
\ No newline at end of file
